@@ -43,6 +43,9 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILE
     tempd = fileutil.NamedTemporaryDirectory()
     db1fname = os.path.join(tempd.name, TMPDB1FNAME)
     d1 = anydbm.open(db1fname, "n")
+    if VERBOSITY:
+        import whichdb
+        print "database type chosen by anydbm was ", whichdb.whichdb(db1fname)
     tempd.register_file(d1)
     fileutil.remove_if_possible(db1fname)
     db2fname = os.path.join(tempd.name, TMPDB2FNAME)
